from google.oauth2 import service_account
from google.cloud import bigquery


class InxtBQ:
  def __init__(self, key_path):
    credentials = service_account.Credentials.from_service_account_file(
        key_path, scopes=["https://www.googleapis.com/auth/cloud-platform"],
    )
    self.client = bigquery.Client(credentials=credentials,
                                  project=credentials.project_id)

  def store_dataframe(self, df, table_name):
    job = self.client.load_table_from_dataframe(df, table_name)
    return job

  def download_table(self, query):
    dataframe = (
        self.client.query(query)
        .result()
        .to_dataframe(
            # Optionally, explicitly request to use the BigQuery Storage API. As of
            # google-cloud-bigquery version 1.26.0 and above, the BigQuery Storage
            # API is used by default.
            create_bqstorage_client=True,
        )
    )
    return dataframe


customer_schema = [
    'address_city',
    'address_country',
    'address_state',
    'created',
    'email',
    'id',
    'invoice_prefix',
    'livemode',
    'name',
    'subscriptions_data_billing_cycle_anchor',
    'subscriptions_data_cancel_at',
    'subscriptions_data_created',
    'subscriptions_data_current_period_end',
    'subscriptions_data_current_period_start',
    'subscriptions_data_customer',
    'subscriptions_data_default_payment_method',
    'subscriptions_data_id',
    'subscriptions_data_items_data_created',
    'subscriptions_data_items_data_id',
    'subscriptions_data_items_data_object',
    'subscriptions_data_items_data_plan_active',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_id',
    'subscriptions_data_items_data_plan_imnterval',
    'subscriptions_data_items_data_plan_interval_count',
    'subscriptions_data_items_data_plan_livemode',
    'subscriptions_data_items_data_plan_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_plan_metadata_name',
    'subscriptions_data_items_data_plan_planType',
    'subscriptions_data_items_data_plan_product',
    'subscriptions_data_items_data_price_active',
    'subscriptions_data_items_data_price_id',
    'subscriptions_data_items_data_price_livemode',
    'subscriptions_data_items_data_price_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_price_metadata_name',
    'subscriptions_data_items_data_price_metadata_planType',
    'subscriptions_data_items_data_price_product',
    'subscriptions_data_items_data_price_recurring_interval',
    'subscriptions_data_items_data_price_interval_count',
    'subscriptions_data_items_data_price_trial_period_days',
    'subscriptions_data_items_data_price_unit_amount',
    'subscriptions_data_items_data_price_type',
    'subscriptions_data_items_data_subscription',
    'subscriptions_latest_invoice',
    'subscriptions_data_discount_checkout_session',
    'subscriptions_data_discount_coupon_amount_off',
    'subscriptions_data_discount_coupon_duration',
    'subscriptions_data_discount_coupon_duration_in_months',
    'subscriptions_data_discount_coupon_name',
    'subscriptions_data_discount_coupon_percent_off',
    'subscriptions_data_discount_id',
    'subscriptions_data_discount_promotion_code',
]



import collections
import json


def flatten(d, parent_key='', sep='_'):
    items = []
    for k, v in d.items():
        new_key = parent_key + sep + k if parent_key else k
        if isinstance(v, collections.MutableMapping):
            items.extend(flatten(v, new_key, sep=sep).items())
        else:
            items.append((new_key, v))
    return dict(items)


def flatten_extract(schema, obj):
  obj = flatten(obj)
  minimum_schema = filter(lambda key: key in obj.keys(), schema)
  return {key: obj[key] for key in minimum_schema}


def extract_schema_data(schema, list):
  return [flatten_extract(schema, item)for item in list]


def flatten_items_list(element_list):
  return [flatten(item) for item in element_list]

# Needs Refactor


def remove_lists(d, key='data'):
  if(not isinstance(d, dict)):
    return d
  new = {}
  for k, v in d.items():
    aux = v
    if isinstance(v, dict):
      aux = remove_lists(v, key)
    if isinstance(v, list) and len(v) > 0:
      aux = v[0]
      aux = remove_lists(aux, key)
    new[k] = aux
  return new


def bulk_remove_lists(l):
  return [remove_lists(json.loads(str(item))) for item in l]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['internxt_data_test']

package_data = \
{'': ['*']}

install_requires = \
['google-cloud-bigquery>=2.34.2,<3.0.0', 'stripe>=2.68.0,<3.0.0']

setup_kwargs = {
    'name': 'internxt-data-test',
    'version': '0.1.6',
    'description': '',
    'long_description': None,
    'author': 'Joan Mora',
    'author_email': 'elcorreudejoanmora@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<3.11',
}


setup(**setup_kwargs)
